# aiolimit

[![Build Status](https://travis-ci.org/jiamo/aiolimit.svg?branch=master)](https://travis-ci.org/jiamo/aiolimit)
[![Python Version](https://img.shields.io/pypi/pyversions/aiolimit.svg)](https://pypi.python.org/pypi/aiolimit)
[![Version](https://img.shields.io/pypi/v/aiolimit.svg)](https://pypi.python.org/pypi/aiolimit)
[![Format](https://img.shields.io/pypi/format/aiolimit.svg)](https://pypi.python.org/pypi/aiolimit)
[![License](https://img.shields.io/pypi/l/aiolimit.svg)](https://pypi.python.org/pypi/aiolimit)
[![codecov](https://codecov.io/gh/jiamo/aiolimit/branch/master/graph/badge.svg)](https://codecov.io/gh/jiamo/aiolimit)

async api rate limit modified and inspired by [redis-token-bucke](https://github.com/Windfarer/redis-token-bucket/blob/master/redis_token_bucket.py).

## Installation

~~~
pip install aiolimit
~~~

## test
~~~
py.test
~~~
